@@ -112,6 +112,8 @@ int main(int argc, char **argv)
 
     about.addAuthor(i18n("Armin Berres"), i18n("Current author"), QStringLiteral("armin@space-based.de"));
     about.addAuthor(i18n("Hans van Leeuwen"), i18n("Original author"), QStringLiteral("hanz@hanz.nl"));
+    about.addAuthor(i18n("Armin Berres"), i18n("Current author"), QStringLiteral("armin@space-based.de"), QString());
+    about.addAuthor(i18n("Hans van Leeuwen"), i18n("Original author"), QStringLiteral("hanz@hanz.nl"), QString());
     KAboutData::setApplicationData(about);
 
     QCommandLineParser parser;
@@ -166,7 +168,7 @@ int main(int argc, char **argv)
         if (wallet.get()) {
             flag = KPasswordDialog::ShowKeepPassword;
         }
-        QPointer<KPasswordDialog> kpd = new KPasswordDialog(0, flag);
+        QPointer<KPasswordDialog> kpd = new KPasswordDialog(nullptr, flag);
 
         kpd->setPrompt(dialog);
         kpd->setWindowTitle(i18n("Ksshaskpass"));
